{# Support for Sphinx 1.3+ page_source_suffix, but don't break old builds. #}

{% if page_source_suffix %}
{% set suffix = page_source_suffix %}
{% else %}
{% set suffix = source_suffix %}
{% endif %}

{% if meta is defined and meta is not none %}
{% set check_meta = True %}
{% else %}
{% set check_meta = False %}
{% endif %}

{% if check_meta and 'github_url' in meta %}
{% set display_github = True %}
{% endif %}

{% if check_meta and 'bitbucket_url' in meta %}
{% set display_bitbucket = True %}
{% endif %}

<div role="navigation" aria-label="breadcrumbs navigation">
  <ul class="wy-breadcrumbs">
    {% block breadcrumbs %}
      <li><a href="{{ pathto(master_doc) }}">Docs</a> &raquo;</li>
        {% for doc in parents %}
          <li><a href="{{ doc.link|e }}">{{ doc.title }}</a> &raquo;</li>
        {% endfor %}
      <li>{{ title }}</li>
    {% endblock %}
    {% block breadcrumbs_aside %}
      <li class="wy-breadcrumbs-aside">
        {% if pagename != "search" %}
            {% if display_github and pagename in source_file_to_url_map %}
            {% if check_meta and 'github_url' in meta %}
              <!-- User defined GitHub URL -->
              <a href="{{ meta['github_url'] }}" class="fa fa-github"> Edit on GitHub</a>
            {% else %}
            {# Removed: github_version #}
              <a href="{{ source_file_to_url_map[pagename]['url'] }}/blob/master/{{ source_file_to_url_map[pagename]['pagename'] }}" class="fa fa-github"> Edit on GitHub</a>
            {% endif %}
          {% elif display_bitbucket %}
            {% if check_meta and 'bitbucket_url' in meta %}
              <!-- User defined Bitbucket URL -->
              <a href="{{ meta['bitbucket_url'] }}" class="fa fa-bitbucket"> Edit on Bitbucket</a>
            {% else %}
              <a href="https://bitbucket.org/{{ bitbucket_user }}/{{ bitbucket_repo }}/src/{{ bitbucket_version}}{{ conf_py_path }}{{ pagename }}{{ suffix }}" class="fa fa-bitbucket"> Edit on Bitbucket</a>
            {% endif %}
          {% elif show_source and source_url_prefix %}
            <a href="{{ source_url_prefix }}{{ pagename }}{{ suffix }}">View page source</a>
          {% elif show_source and has_source and sourcename %}
            <a href="{{ pathto('_sources/' + sourcename, true)|e }}" rel="nofollow"> View page source</a>
          {% endif %}
        {% endif %}
      </li>
    {% endblock %}
  </ul>
  <hr/>
</div>
