#!{{ ansible_python['executable'] }}

# {{ ansible_managed }}

from __future__ import print_function
from json import dumps
from sys import exit

output = {'installed': True}

print(dumps(output, sort_keys=True, indent=4))
