{% set postgresql_server__tpl_version = ansible_local.postgresql.version if (ansible_local|d() and ansible_local.postgresql|d() and ansible_local.postgresql.version|d()) else postgresql_server__version %}
{% set postgresql_server__tpl_server = ansible_local.postgresql.server if (ansible_local|d() and ansible_local.postgresql|d() and ansible_local.postgresql.server|d()) else "localhost" %}
{% set postgresql_server__tpl_port = ansible_local.postgresql.port if (ansible_local|d() and ansible_local.postgresql|d() and ansible_local.postgresql.port|d()) else "5432" %}
{% set postgresql_server__tpl_delegate_to = ansible_local.postgresql.delegate_to if (ansible_local|d() and ansible_local.postgresql|d() and ansible_local.postgresql.delegate_to|d()) else postgresql_server__delegate_to %}
{% set postgresql_server__tpl_user = ansible_local.postgresql.user if (ansible_local|d() and ansible_local.postgresql|d() and ansible_local.postgresql.user|d()) else postgresql_server__user %}
{
"delegate_to": "{{ postgresql_server__tpl_delegate_to }}",
"password_chars": "{{ postgresql_server__password_characters }}",
"port": "{{ postgresql_server__tpl_port }}",
"server": "{{ postgresql_server__tpl_server }}",
"user": "{{ postgresql_server__tpl_user }}",
"version": "{{ postgresql_server__tpl_version }}"
}
