# {{ ansible_managed }}

[Unit]
Description=Daemon to survery DHCP/BOOTP servers on LAN
After=network-online.target
Documentation=man:dhcp_probe(8)

[Service]
Type=oneshot
ExecStart=/bin/true
ExecReload=/bin/true
RemainAfterExit=yes

[Install]
WantedBy=multi-user.target
