# https://github.com/Mikesch-mp/icingaweb2-module-grafana/blob/master/doc/03-module-configuration.md
[grafana]
version = "1"
host = "{{ icinga_grafana_host }}"
username = "{{ icinga_grafana_admin_user }}"
password = "{{ icinga_grafana_admin_password }}"
protocol = "http"
timerangeAll = "1w/w"
defaultdashboard = "{{ icinga_grafana_title }}"
defaultdashboarduid = "{{ icinga_grafana_uid }}"
defaultdashboardpanelid = "1"
defaultorgid = "1"
shadows = "0"
theme = "light"
accessmode = "proxy"
debug = "0"
directrefresh = "no"
height = "280"
width = "640"
enableLink = "yes"
