# {{ ansible_managed }}

# This can be used to setup URI aliases for frequently
# used connection URIs. Aliases may contain only the
# characters  a-Z, 0-9, _, -.
#
# Following the '=' may be any valid libvirt connection
# URI, including arbitrary parameters

uri_aliases = [
{% for key, value in libvirtd__uri_aliases.items() %}
    "{{ key + '=' + value }}",
{% endfor %}
]

#
# These can be used in cases when no URI is supplied by the application
# (@uri_default also prevents probing of the hypervisor driver).
#
uri_default = "{{ libvirtd__uri_aliases[libvirtd__default_uri] }}"
