# This file is managed by Ansible, all changes will be lost

# Send copy of SMS gateway logs to a separate log file for accounting
if $programname == 'sms-transport' then {{ smstools_sms_log }}
if $programname == 'sms-service' then {{ smstools_sms_log }}

