# {{ ansible_managed }}

# environment variables for postmaster process
# This file has the same syntax as postgresql.conf:
#  VARIABLE = simple_value
#  VARIABLE2 = 'any value!'
# I. e. you need to enclose any value which does not only consist of letters,
# numbers, and '-', '_', '.' in single quotes. Shell commands are not
# evaluated.

{% if item.environment is defined and item.environment %}
{% for key, value in item.environment.items() %}
{{ key }} = '{{ value }}'
{% endfor %}
{% endif %}


