set_var EASYRSA_REQ_COUNTRY    "{{ openvpn_country }}"
set_var EASYRSA_REQ_PROVINCE   "{{ openvpn_province }}"
set_var EASYRSA_REQ_CITY       "{{ openvpn_city }}"
set_var EASYRSA_REQ_ORG        "{{ openvpn_org }}"
set_var EASYRSA_REQ_EMAIL      "{{ openvpn_email }}"
set_var EASYRSA_REQ_OU         "{{ openvpn_ou }}"
