# {{ ansible_managed }}

{% if machine__organization|d() %}
ORGANIZATION="{{ machine__organization }}"
{% endif %}
{% if machine__contact|d() %}
CONTACT="{{ machine__contact }}"
{% endif %}
{% if machine__pretty_hostname|d() %}
PRETTY_HOSTNAME="{{ machine__pretty_hostname }}"
{% endif %}
{% if machine__icon_name|d() %}
ICON_NAME="{{ machine__icon_name }}"
{% endif %}
{% if machine__chassis|d() %}
CHASSIS="{{ machine__chassis }}"
{% endif %}
{% if machine__deployment|d() %}
DEPLOYMENT="{{ machine__deployment }}"
{% endif %}
{% if machine__location|d() %}
LOCATION="{{ machine__location }}"
{% endif %}
