# {{ ansible_managed }}

# Number of servers to start up
RPCNFSDCOUNT={{ nfs_server__threads }}

# Runtime priority of server (see nice(1))
RPCNFSDPRIORITY={{ nfs_server__priority }}

# Options for rpc.mountd.
# If you have a port-based firewall, you might want to set up
# a fixed port here using the --port option. For more information,
# see rpc.mountd(8) or http://wiki.debian.org/SecuringNFS
# To disable NFSv4 on the server, specify '--no-nfs-version 4' here
RPCMOUNTDOPTS="{{ nfs_server__mountd_options if nfs_server__mountd_options is string else nfs_server__mountd_options | join(' ') }}"

# Do you want to start the svcgssd daemon? It is only required for Kerberos
# exports. Valid alternatives are "yes" and "no"; the default is "no".
NEED_SVCGSSD="{{ 'yes' if nfs_server__kerberos | bool else 'no' }}"

# Options for rpc.svcgssd.
RPCSVCGSSDOPTS="{{ nfs_server__svcgssd_options if nfs_server__svcgssd_options is string else nfs_server__svcgssd_options | join(' ') }}"
