<?php
/* {{ ansible_managed }} */

/* Local DokuWiki configuration options which are not configurable using the
   Configuration Manager interface */

{{ dokuwiki__protected_conf_php | regex_replace('\n$','') }}
