# {{ ansible_managed }}

default: &defaults
    {{ foodsoft__database_config.production | to_nice_yaml | indent(4) }}

development:
  <<: *defaults

test:
  <<: *defaults

production:
  <<: *defaults
