# This file is managed by Ansible, all changes will be lost

# List of regexps of strings to remove from SMS messages
{% if smstools_mail_msgdel_list is defined and smstools_mail_msgdel_list %}
{% for regexp in smstools_mail_msgdel_list %}
{{ regexp }}
{% endfor %}
{% endif %}

