## {{ ansible_managed }}

# The VCS to use.
VCS="{{ etckeeper__vcs }}"

# Options passed to git commit when run by etckeeper.
GIT_COMMIT_OPTIONS="{{ etckeeper__git_commit_options }}"

# Options passed to hg commit when run by etckeeper.
HG_COMMIT_OPTIONS="{{ etckeeper__hg_commit_options }}"

# Options passed to bzr commit when run by etckeeper.
BZR_COMMIT_OPTIONS="{{ etckeeper__bzr_commit_options }}"

# Options passed to darcs record when run by etckeeper.
DARCS_COMMIT_OPTIONS="{{ etckeeper__darcs_commit_options }}"

# Uncomment to avoid etckeeper committing existing changes
# to /etc automatically once per day.
AVOID_DAILY_AUTOCOMMITS={{ '1' if (etckeeper__avoid_daily_autocommits|d() | bool) else '0' }}

# Uncomment the following to avoid special file warning
# (the option is enabled automatically by cronjob regardless).
AVOID_SPECIAL_FILE_WARNING={{ '1' if (etckeeper__avoid_special_file_warning|d() | bool) else '0' }}

# Uncomment to avoid etckeeper committing existing changes to
# /etc before installation. It will cancel the installation,
# so you can commit the changes by hand.
AVOID_COMMIT_BEFORE_INSTALL={{ '1' if (etckeeper__avoid_commit_before_install|d() | bool) else '0' }}

# The high-level package manager that's being used.
# (apt, pacman-g2, yum, dnf, zypper etc)
HIGHLEVEL_PACKAGE_MANAGER={{ etckeeper__highlevel_package_manager }}

# The low-level package manager that's being used.
# (dpkg, rpm, pacman, pacman-g2, etc)
LOWLEVEL_PACKAGE_MANAGER={{ etckeeper__lowlevel_package_manager }}

# To push each commit to a remote, put the name of the remote here.
# (eg, "origin" for git). Space-separated lists of multiple remotes
# also work (eg, "origin gitlab github" for git).
PUSH_REMOTE="{{ etckeeper__push_remote }}"
