# {{ ansible_managed }}

[Unit]
Description=Docker Registry service
ConditionPathExists=/var/lib/docker-registry
After=network.target network-online.target

[Service]
Type=simple
User={{ docker_registry__user }}
Group={{ docker_registry__group }}
WorkingDirectory={{ docker_registry__home }}
ExecStart={{ docker_registry__binary }} serve {{ docker_registry__config_file }}
Restart=on-failure
RestartSec=10

StandardOutput=syslog
StandardError=syslog
SyslogIdentifier=docker-registry

[Install]
WantedBy=multi-user.target
