# {{ ansible_managed }}

# memcached default config file
# 2003 - Jay Bonci <jaybonci@debian.org>
# This configuration file is read by the start-memcached script provided as
# part of the Debian GNU/Linux distribution.

# Run memcached as a daemon. This command is implied, and is not needed for the
# daemon to run. See the README.Debian that comes with this package for more
# information.
-d

# Log memcached's output to /var/log/memcached
logfile /var/log/memcached.log

# Be verbose
# -v

# Be even more verbose (print client commands as well)
# -vv

# Start with a cap of {{ memcached_memory }} megs of memory. Note that the
# daemon will grow to this size, but does not start out holding this much
# memory
-m {{ memcached_memory }}

# Default connection port is 11211
-p 11211

# Run the daemon as memcache. The start-memcached will default to running as root if no
# -u command is present in this config file
-u memcache

# Specify which IP address to listen on. The default is to listen on all IP addresses
# This parameter is one of the only security measures that memcached has, so make sure
# it's listening on a firewalled interface.
-l {{ memcached_bind }}

# Limit the number of simultaneous incoming connections. The daemon default is 1024
-c {{ memcached_connections }}

# Lock down all paged memory. Consult with the README and homepage before you do this
# -k

# Return error when memory is exhausted (rather than removing items)
# -M

# Maximize core file limit
# -r

{% if memcached_options|d() and memcached_options %}
{{ memcached_options }}
{% endif %}
