Key-Type: {{ reprepro_gpg_key_type | default('RSA') }}
Subkey-Type: {{ reprepro_gpg_key_type | default('RSA') }}
Key-Length: {{ reprepro_gpg_key_length | default('4096') }}
Subkey-Length: {{ reprepro_gpg_key_length | default('4096') }}
Name-Real: {{ reprepro_gpg_name }}
Name-Email: {{ reprepro_gpg_email }}
Expire-Date: {{ reprepro_gpg_expire_days }}
%no-ask-passphrase
%no-protection
%commit
