# {{ ansible_managed }}

# Configuration for 'rsnapshot-scheduler' script

# Directory where rsnapshot configuration is stored
scheduler_config_dir="{{ rsnapshot__config_dir }}"

# Directory where backup snapshots are stored
scheduler_snapshot_root="{{ rsnapshot__snapshot_root }}"

# How backup jobs should be scheduled, either "batch" or "sleep"
scheduler_type="{{ rsnapshot__scheduler_type }}"

# Command used to schedule backup jobs in 'at'
scheduler_batch_command="{{ rsnapshot__scheduler_batch_command }}"

# Sleep scheduler uses 'sleep' command with a random time in minutes before
# starting the backup. This variable defined maximum delay in minutes.
scheduler_sleep_max_delay="{{ rsnapshot__scheduler_sleep_max_delay }}"

# When another instance of 'rsnapshot-scheduler' is detected which manages
# backup for different snapshot level, scheduler script will sleep for this
# amonut of minutes before checking again if it's OK to proceed.
scheduler_run_max_delay="{{ rsnapshot__scheduler_run_max_delay }}"

