{% set gitlab__tpl_systemd_services = (ansible_local.gitlab.systemd_services if (ansible_local|d() and ansible_local.gitlab|d() and ansible_local.gitlab.systemd_services|d()) else gitlab_use_systemd) %}
{% set gitlab__tpl_database = (ansible_local.gitlab.database if (ansible_local|d() and ansible_local.gitlab|d() and ansible_local.gitlab.database|d()) else gitlab__database) %}
{
"database": "{{ gitlab__tpl_database }}",
"fqdn": "{{ gitlab__fqdn }}",
"installed": true,
"registry": {{ gitlab__registry_enabled | bool | lower }},
"registry_pki_realm": "{{ gitlab__registry_pki_realm }}",
"registry_token_realm_url": "{{ gitlab__registry_token_realm_url }}",
"registry_token_issuer": "{{ gitlab__registry_token_issuer }}",
"registry_token_service": "{{ gitlab__registry_token_service }}",
"systemd_services": {{ gitlab__tpl_systemd_services | bool | lower }},
"version": "{{ gitlab_version }}"
}
