# {{ ansible_managed }}
# Source: https://home-assistant.io/docs/autostart/systemd/

[Unit]
Description=Home Assistant
After=network.target

[Service]
Type=simple
User={{ homeassistant__user }}
ExecStart={{ homeassistant__daemon_path }}

[Install]
WantedBy=multi-user.target
