{% set snmpd__tpl_username = (ansible_local.snmpd.username
                              if (ansible_local|d() and ansible_local.snmpd|d() and
                                  ansible_local.snmpd.username)
                              else snmpd_account_local_username) %}
{% set snmpd__tpl_password = (ansible_local.snmpd.password
                              if (ansible_local|d() and ansible_local.snmpd|d() and
                                  ansible_local.snmpd.password)
                              else snmpd_account_local_password) %}
{% set output = {"username": snmpd__tpl_username,
                 "password": snmpd__tpl_password} %}
{{ output | to_nice_json }}
