{% if reprepro_installer_jessie_compatibility %}
{% set digest_preference = 'SHA256 SHA224' %}
{% else %}
{% set digest_preference = 'SHA512 SHA384 SHA256 SHA224' %}
{% endif %}
# This file is managed remotely, all changes will be lost

# GPG Configuration Options
default-recipient-self
list-options show-uid-validity show-keyserver-urls
verify-options show-uid-validity
display-charset utf-8
utf8-strings
trust-model pgp
ask-cert-level
default-cert-level 0
keyid-format 0xlong
no-greeting

# GPG Input/Output Options
armor
fixed-list-mode

# OpenPGP Options
personal-digest-preferences {{ digest_preference }}

# GPG Esoteric Options
default-preference-list {{ digest_preference }} AES256 AES192 AES CAST5 BZIP2 ZLIB ZIP Uncompressed
cert-digest-algo {{ 'SHA256' if  reprepro_installer_jessie_compatibility else 'SHA512' }}
no-comments
no-emit-version

sig-notation issuer-fpr@notations.openpgp.fifthhorseman.net=%g

