// {{ ansible_managed }}

// Should APT install recommended or suggested packages?
APT::Install-Recommends "{{ apt__install_recommends | bool | lower }}";
APT::Install-Suggests "{{ apt__install_suggests | bool | lower }}";
