# {{ ansible_managed }}

# Override the default ExecStart and ExecStop commands in the main
# 'lxc.service' unit to prevent accidental launch of LXC containers
# not supervised by systemd

[Service]
ExecStart=
ExecStart=/bin/true

ExecStop=
ExecStop=/bin/true
