.big-box {
  border: 1px solid #eee;
  -webkit-box-shadow: 0 3px 3px rgba(0,0,0,.5);
  box-shadow: 0 3px 3px rgba(0,0,0,.5);
  padding: 20px;
  margin-top: 60px;
  margin-bottom: 60px;

/*
  -webkit-box-shadow:0 1px 4px rgba(0, 0, 0, 0.3), 0 0 40px rgba(0, 0, 0, 0.1) inset;
     -moz-box-shadow:0 1px 4px rgba(0, 0, 0, 0.3), 0 0 40px rgba(0, 0, 0, 0.1) inset;
          box-shadow:0 1px 4px rgba(0, 0, 0, 0.3), 0 0 40px rgba(0, 0, 0, 0.1) inset;
*/
}


.socialaccount_providers li a.socialaccount_provider {
  rem-border: 1px solid #ddd;
  border-radius: 10px;
  rem-box-shadow: 2px 2px 8px rgba(0,0,0,.7);
  -padding: 10px;
  margin-bottom: 6px;
  display: block;
  width: 100%;
  overflow: hidden;
  rem-font-size: 1.2em;
}

.socialaccount_providers li a.socialaccount_provider:hover {
  text-decoration: none;
  box-shadow: 1px 1px 2px rgba(0,0,0,.7);
}

.socialaccount_providers li a.socialaccount_provider.facebook {
  background: #4B67A3; /* technically gradient down to #3A579A */
  color: #fff;
}
.socialaccount_providers li a.socialaccount_provider.facebook:before {
  font-family: FontAwesome;
  font-size: 1.9em;
  content: "\f082";
  display: inline-block;
  padding-left: 8px;
  padding-right: 8px;
}

.socialaccount_providers li a.socialaccount_provider.google {
  background: #DE4931;
  color: #fff;
}
.socialaccount_providers li a.socialaccount_provider.google:before {
  font-family: FontAwesome;
  font-size: 1.9em;
  content: "\f1a0";
  display: inline-block;
  padding-left: 8px;
  padding-right: 8px;
}


/* from http://konigi.com/tools/css-sticky-notes */
.sticky {
  -webkit-box-shadow: #DDD 0px 1px 2px;
  position: relative;
  background-color: #F4F39E;
  border-color: #DEE184;
  text-align: center;
  margin: 2.5em 0px;
  padding: 1.5em 1em;
  -webkit-box-shadow: 0px 1px 3px rgba(0,0,0,0.25);
  -moz-box-shadow: 0px 1px 3px rgba(0,0,0,0.25);
  box-shadow: 0px 1px 3px rgba(0,0,0,0.25);
  font-family: Chalkboard, 'Comic Sans';
}
.sticky.taped2:after {
  display: block;
  content: "";
  position: absolute; 
  width: 110px;
  height: 30px;
  top: -21px;
  left: 30%;    
  border: 1px solid #fff;
  background: rgba(254, 254, 254, .6);
  -webkit-box-shadow: 0px 0 3px rgba(0,0,0,0.1);
  -moz-box-shadow: 0px 0 3px rgba(0,0,0,0.1);
  box-shadow: 0px 0 3px rgba(0,0,0,0.1);  
}

/* borrowed from http://designshack.net/articles/css/4-fun-css-image-effects-you-can-copy-and-paste/ */
.picture-frame img {
  border: 10px solid #fff;
  -webkit-box-shadow: 3px 0px 0px #777;
  -moz-box-shadow: 3px 0px 0px #777;
  box-shadow: 0px 0px 5px rgba(0,0,0,0.35);
}
