{% extends "debian.cfg.j2" %}
{% block warning %}
###########################################################
## WARNING - THIS FILE DESTROYS HARD DISK AND OTHER DATA ##
## DEVICES. USE AT YOUR OWN RISK. BE SMART. ANY LOSS OF  ##
##     DATA DUE TO USE OF THIS FILE IS NOT OUR FAULT     ##
###########################################################

{% endblock %}
{% block partman %}
# This destroys the disk!
d-i partman-auto/method string regular
d-i partman-auto/expert_recipe string				\
{% if item.partman_recipe is defined and item.partman_recipe %}
{{ item.partman_recipe }}
{% else %}
	boot-root ::						\
		1000 10000 1000000000 {{ item.filesystem | default(preseed__debian_filesystem | default('ext4')) }}			\
			$primary{ } $bootable{ }		\
			method{ format } format{ }		\
			use_filesystem{ } filesystem{ {{ item.filesystem | default(preseed__debian_filesystem | default('ext4')) }} }	\
			mountpoint{ / } label{ System }		\
		.
{% endif %}
{% if item.partman_swap is undefined or not item.partman_swap %}
d-i partman-basicfilesystems/no_swap boolean false
{% endif %}
d-i partman-partitioning/confirm_write_new_label boolean true
d-i partman/choose_partition select finish
d-i partman/confirm boolean true
d-i partman/confirm_nooverwrite boolean true
d-i partman/mount_style select uuid
{% endblock %}
{% block grub_installer %}

d-i grub-installer/bootdev string default
{% endblock %}

