# {{ ansible_managed }}

[Definition]

actionstart = {{ item.start | d('') | indent(14) }}

actionstop = {{ item.stop | d('') | indent(13) }}

actioncheck = {{ item.check | d('') | indent(14) }}

actionban = {{ item.ban | indent(12) }}

actionunban = {{ item.unban | d('') | indent(14) }}
