# {{ ansible_managed }}

# Warning: this file is created by Ansible 'assemble' module, that combines
# files in /etc/hosts.allow.d/ directory into file /etc/hosts.allow. Do not
# modify this file directly, instead put your additions in the
# /etc/hosts.allow.d/ directory with a proper name, preferably after diverted
# original /etc/hosts.allow. Your changes will be included and preserved on the
# next Ansible run.
#
{% if tcpwrappers__enabled | bool %}
# Original /etc/hosts.allow has been diverted to {{ tcpwrappers__divert_hosts_allow }}
# Original contents follow.
{% else %}
# /etc/hosts.allow diversion is not active, contents of /etc/hosts.allow.d/ won't be
# included in /etc/hosts.allow
{% endif %}

