# {{ ansible_managed }}

[{{ debops_fact__default_section }}]
enabled = true
public_facts = "{{ debops_fact__public_path }}"
public_section = "{{ debops_fact__public_section }}"
default_section = "{{ debops_fact__default_section }}"

[{{ debops_fact__public_section }}]
