Name: activate mkhomedir managed by Ansible
Default: yes
Priority: 900
Session-Type: Additional
Session:
        required                        pam_mkhomedir.so umask={{ nslcd__mkhomedir_umask }} skel=/etc/skel
