# This file is managed by Ansible, all changes will be lost

# Postfix transport_maps configuration to relay mail messages to SMS gateway
{{ "%-40s %s" | format(smstools_mail_transport_domain, smstools_service_name + ":") }}

