{{ ({
    "enabled": True,
    "database": volkszaehler__database,
    "webserver": volkszaehler__webserver,
    (volkszaehler__database + "_initialized"): True,
    (volkszaehler__database + "_demo_insert"): volkszaehler__database_demo_insert|bool,
}) | to_nice_json }}
