{% import 'unattended_upgrades__tpl_macros.j2' as unattended_upgrades__tpl_macros with context %}
{{ ({
      "enabled":   unattended_upgrades__enabled  | bool | lower,
      "periodic":  unattended_upgrades__periodic | bool | lower,
      "blacklist": unattended_upgrades__tpl_macros.get_blacklist_as_json() | from_json,
      "origins":   unattended_upgrades__tpl_macros.get_origins_as_json()   | from_json,
}) | to_nice_json }}
