<?php
/**
 * This is an example of how a local.php could look like.
 * Simply copy the options you want to change from dokuwiki.php
 * to this file and change them.
 *
 * When using the installer, a correct local.php file be generated for
 * you automatically.
 */

$conf['title'] = 'Wiki Title';
$conf['useacl'] = 1;
$conf['superuser'] = '@admin';
