# {{ ansible_managed }}

# SNMP client configuration

defVersion         {{ librenms__snmp_version }}

defCommunity       {{ librenms__snmp_communities[0] }}

defSecurityLevel   {{ librenms__fact_snmp_v3_authlevel }}
defAuthType        {{ librenms__fact_snmp_v3_authalgo }}
defPrivType        {{ librenms__fact_snmp_v3_cryptoalgo }}

defSecurityName    {{ librenms__fact_snmp_v3_authname }}
defAuthPassphrase  {{ librenms__fact_snmp_v3_authpass }}
defPrivPassphrase  {{ librenms__fact_snmp_v3_cryptopass }}
