# {{ ansible_managed }}

# /etc/default/tftpd-hpa

TFTP_USERNAME="{{ tftpd__username }}"
TFTP_DIRECTORY="{{ tftpd__directory }}"
TFTP_ADDRESS="{{ tftpd__address }}"
TFTP_OPTIONS="{{ q('flattened', ([ tftpd__options ] if tftpd__options is string else tftpd__options)) | join(' ') }}"
