# This file is managed by Ansible, all changes will be lost

# TODO: Finish configuration when mail system is ready

# /etc/sks/mailsync
#
# The mailsync should contains a list of email addresses of PKS
# keyservers, one per line. This file is important, because it ensures
# that keys submitted directly to an SKS keyserver are also forwarded
# to PKS keyservers.
#
# Empty lines and whitespace-only lines are ignored, as are lines
# whose first non-whitespace character is a `#'.
#
# IMPORTANT: don't add someone to your mailsync file without getting
# their permission first!
#
# Jonathan McDowell <pgp-keyserver-admin@earth.li> says that having
# his keyserver's address in the Debian package is fine.
#pgp-public-keys@the.earth.li


