{
  "backend_servers": [{
    "title": "{{ domain }}",
    "domain": "psono.{{ domain }}",
    "url": "https://psono-server.{{ domain }}"
  }],
  "base_url": "https://psono.{{ domain }}/",
  "allow_custom_server": true,
  "allow_registration": true,
  "allow_lost_password": true,
  "disable_download_bar": false,
  "authentication_methods": ["AUTHKEY", "LDAP"],
  "saml_provider": []
}
