{% set mosquitto__tpl_anonymous = mosquitto__allow_anonymous %}
{% set mosquitto__tpl_password = mosquitto__password %}
{
"anonymous": {{ mosquitto__tpl_anonymous | bool | lower }},
"installed": true,
"password": {{ mosquitto__tpl_password | bool | lower }}
}
