# This file is managed by Ansible, all changes will be lost

# Configuration for sms-transport mail service

# Path to sendsms script to be used to send SMS messages
sendsms = {{ smstools_mail_transport_sendsms }}

# Path to file with list of allowed or denied sender addresses/domains
senders = {{ smstools_mail_transport_senders }}

# Max length of an SMS message to send
maxchars = {{ smstools_mail_transport_maxchars }}

# Regexp list of strings to remove from SMS messages
msgdel = {{ smstools_mail_transport_msgdel }}

# Debug option, change to 1 to make scripts more verbose
debug = 0

