{% set minio__tpl_etc_services_dependent_list = [] %}
{% for element in minio__combined_instances | parse_kv_items %}
{%   if (element.name|d() and element.port|d() and element.state|d('present') not in [ 'ignore', 'init' ]) %}
{%     set rule = {'name': ('minio-' + element.name),
                   'port': element.port,
                   'protocol': [ 'tcp' ],
                   'state': element.state} %}
{%     set _ = minio__tpl_etc_services_dependent_list.append(rule) %}
{%   endif %}
{% endfor %}
{{ minio__tpl_etc_services_dependent_list | to_yaml }}
