# {{ ansible_managed }}

# etherpad-lite system configuration

# Installation directory
EPLITE_DIR="{{ etherpad_home + '/' + etherpad_repository }}"

# System user
USER="{{ etherpad_user }}"

# System group
GROUP="{{ etherpad_group }}"

