# {{ ansible_managed }}

[Unit]
Description=Icinga 2 Director job runner

[Service]
Type=simple
ExecStart=/usr/bin/icingacli director jobs run --forever
Restart=on-success

[Install]
WantedBy=multi-user.target
