# {{ ansible_managed }}

[{{ debops_fact__default_section }}]
private_facts = "{{ debops_fact__private_path }}"
private_section = "{{ debops_fact__private_section }}"

[{{ debops_fact__private_section }}]
