# This file is managed by Ansible, all changes will be lost

{% for key, value in rails_deploy_default_env.items() -%}
export {{ key }}='{{ value }}'
{% endfor -%}
{% for key, value in rails_deploy_env.items() -%}
export {{ key }}='{{ value }}'
{% endfor -%}
