# {{ ansible_managed }}

# Kernel upgrade hints are disabled to allow for non-interactive APT package
# installs. Without this, non-interactive APT operations, for example performed
# by Ansible, will hang indefinitely - waiting for user interaction.
$nrconf{kernelhints} = 0;
