# {{ ansible_managed }}

# Extra options to be passed to tincd.
EXTRA="{{ tinc__extra_options }}"

# Limits to be configured for the tincd process. Please read your shell
# (pointed by /bin/sh) documentation for ulimit. You probably want to raise the
# max locked memory value if using both --mlock and --user flags.
LIMITS="{{ tinc__ulimit_options | default('-l 1024') }}"
