# {{ ansible_managed }}
#
# Warning: This file is created by Ansible 'assemble' module, that combines
# files in `/etc/services.d/` directory into file /etc/services. Do not modify
# this file directly, instead put your additions in the `/etc/services.d/`
# directory with a proper name, preferably after diverted original
# `/etc/services`.
#
{% if etc_services__enabled|d() %}
# Original `/etc/services` has been diverted to {{ etc_services__diversion }}
# Original contents follow.
{% else %}
# `/etc/services` diversion is not active, contents of /etc/services.d/ won't be
# included in `/etc/services`.
{% endif %}


