# {{ ansible_managed }}

[core]
	autocrlf	= input

[user]
	name		= {{ gitlab_email_name | default('GitLab') }}
	email		= {{ gitlab_email_from | default('git@' + gitlab__fqdn) }}

{% if gitlab_version is version_compare("8.7", operator="ge", strict=True) %}
[gc]
	auto		= 0
{% endif %}

[repack]
	writeBitmaps = true
