# This file is managed by Ansible, all changes will be lost

{{ smstools_sms_log }} {
	rotate {{ smstools_sms_log_rotation_interval | default('52') }}
	{{ smstools_sms_log_rotation | default('weekly') }}
	missingok
	notifempty
	compress
	delaycompress
}


