{# Use the generic versions where possible. The role might support multipe persistant storage providers. #}
{{ ({
    "enabled": persistent_paths__qubes_os_enabled|bool,
    "write_to_storage_path": persistent_paths__qubes_os_enabled|bool,
    "storage_path": persistent_paths__qubes_os_storage_path|string,
    "default_persistent_paths": persistent_paths__qubes_os_default_persistent_paths,
    "qubes_os_enabled": persistent_paths__qubes_os_enabled|bool,
    "qubes_os_config_dir": persistent_paths__qubes_os_config_dir|string,
    "qubes_os_storage_path": persistent_paths__qubes_os_storage_path|string,
    "qubes_os_handler": persistent_paths__qubes_os_handler|string,
    "qubes_os_default_persistent_paths": persistent_paths__qubes_os_default_persistent_paths,
}) | to_nice_json }}
