# {{ ansible_managed }}

# This file describes the network interfaces available on your system
# # and how to activate them. For more information, see interfaces(5).

# The loopback network interface
auto lo
iface lo inet loopback

# Read interface configuration from other files
source /etc/network/interfaces.d/*
