# {{ ansible_managed }}

# SNMP client configuration

defVersion         v3

defSecurityLevel   authPriv
defAuthType        SHA
defPrivType        AES

defSecurityName    {{ snmpd_account_local_username }}
defPassphrase      {{ snmpd_account_local_password }}

