# This file is managed by Ansible, all changes will be lost

disc0
{
	SetNumber = 0
	BlockSize = {{ boxbackup_storage_blocksize.stdout | default('4096') }}
	Dir0 = {{ boxbackup_storage }}/
	Dir1 = {{ boxbackup_storage }}/
	Dir2 = {{ boxbackup_storage }}/
}


