# {{ ansible_managed }}

# systemd service for managing all Green Unicorn instances on the host

[Unit]
Description=Green Unicorn - Python application server

[Service]
Type=oneshot
ExecStart=/bin/true
ExecReload=/bin/true
RemainAfterExit=yes

[Install]
WantedBy=multi-user.target
