# This file is managed by Ansible, all changes will be lost

# Postfix rewrite map used to rewrite short recipient addresses to long
# recipient addresses for SMS messages
{{ "%-40s %s" | format('@' + smstools_mail_alias_subdomain, '@' + smstools_mail_alias_domain) }}
{{ "%-40s %s" | format('@' + smstools_mail_transport_subdomain, '@' + smstools_mail_transport_domain) }}

