ca:
   root:
      dn: CN=root.ca.{{ domain_name }},OU=CA,O={{ domain_name }}\, Inc.,DC={{ domain_name }}
      keysize: 2048
      validityDays: 730
      pkPassword: none
      file: root-ca.pem

### Default values and global settings
defaults:
      validityDays: 730
      pkPassword: none
      # Set this to true in order to generate config and certificates for
      # the HTTP interface of nodes
      httpsEnabled: true
      reuseTransportCertificatesForHttp: false
      verifyHostnames: false
      resolveHostnames: false

###
### Nodes
###
#
# Specify the nodes of your ES cluster here
#
nodes:
{% for (key,value) in instances.items() %}
{% if (value.ip is defined and value.ip | length > 0) %}
  - name: {{ value.name }}
    dn: CN={{ value.name }}.{{ domain_name }},OU=Ops,O={{ domain_name }}\, Inc.,DC={{ domain_name }}
    dns: {{ value.name }}.{{ domain_name }}
    ip: {{ value.ip }}
{% endif %}
{% endfor %}
###
### Clients
###
#
# Specify the clients that shall access your ES cluster with certificate authentication here
#
# At least one client must be an admin user (i.e., a super-user). Admin users can
# be specified with the attribute admin: true
#
clients:
  - name: admin
    dn: CN=admin.{{ domain_name }},OU=Ops,O={{ domain_name }}\, Inc.,DC={{ domain_name }}
    admin: true
