# {{ ansible_managed }}
{#

This file follows the upstream default configuration except for the parts
that are configurable via DebOps variables. If you need a more customized
setup, you can provide your own template via lookup mechanism.

#}
{% import 'dovecot_macros.j2' as macros with context %}

##
## LMTP specific settings
##

{% if dovecot_lmtp_config_map is defined and dovecot_lmtp_config_map %}
{%   if 'protocol' in dovecot_lmtp_config_map %}
{%     set dovecot_tpl_lmtp_proto_map = dovecot_lmtp_config_map['protocol'] %}
{%   endif %}
{% endif %}
{{ macros.dovecot_cfg_section('protocol', 'lmtp', dovecot_tpl_lmtp_proto_map|default({})) }}
