# This file is managed by Ansible, all changes will be lost

{{ rails_deploy_log }}/*.log {
        {{ rails_deploy_logrotate_interval }}
        missingok
        copytruncate
        create 0640 {{ rails_deploy_service }} {{ rails_deploy_service }}
        rotate {{ rails_deploy_logrotate_rotation }}
        compress
        notifempty
}
