# {{ ansible_managed }}

[Unit]
Description=GitLab Slice
Requires=redis-server.service
Wants=postgresql.service gitlab-gitaly.service gitlab-unicorn.service gitlab-sidekiq.service gitlab-workhorse.service gitlab-mailroom.service
{% if gitlab_enable_pages|bool %}
Wants=gitlab-pages.service
{% endif %}
Before=slices.target
After=redis-server.service postgresql.service

[Install]
WantedBy=multi-user.target
