# {{ ansible_managed }}
#
# /etc/default/openntpd

# Append '-s' to set the system time when starting in case the offset
# between the local clock and the servers is more than 180 seconds.
# For other options, see man ntpd(8).
DAEMON_OPTS="{{ ntp__openntpd_options }}"
