# {{ ansible_managed }}

# GitLab user. git by default
user: {{ gitlab_user }}

# Url to gitlab instance. Used for api calls. Should end with a slash.
# Default: http://localhost:8080/
# You only have to change the default if you have configured Unicorn
# to listen on a custom port, or if you have configured Unicorn to
# only listen on a Unix domain socket.
gitlab_url: "http://localhost:{{ gitlab_unicorn_port | default('8080') }}/"

# See installation.md#using-https for additional HTTPS configuration details.
http_settings:
#  user: someone
#  password: somepass
#  ca_file: /etc/ssl/cert.pem
#  ca_path: /etc/pki/tls/certs
  self_signed_cert: false

# Repositories path
# Give the canonicalized absolute pathname,
# REPOS_PATH MUST NOT CONTAIN ANY SYMLINK!!!
# Check twice that none of the components is a symlink, including "/home".
repos_path: "{{ gitlab_repositories_path }}"

# File used as authorized_keys for gitlab user
auth_file: "{{ gitlab_home }}/.ssh/authorized_keys"

# Redis settings used for pushing commit notices to gitlab
redis:
  bin: /usr/bin/redis-cli
  host: {{ gitlab_redis_host | default('127.0.0.1') }}
  port: {{ gitlab_redis_port | default('6379') }}
{% if gitlab_redis_password %}
  pass: {{ gitlab_redis_password }}
{% else %}
  # pass: redispass
{% endif %}
  database: 0
  # socket: /tmp/redis.socket # Only define this if you want to use sockets
  namespace: resque:gitlab

# Log file.
# Default is gitlab-shell.log in the root directory.
log_file: "{{ gitlab_app_root_path }}/gitlab-shell/gitlab-shell.log"

# Log level. INFO by default
log_level: INFO

# Audit usernames.
# Set to true to see real usernames in the logs instead of key ids, which is easier to follow, but
# incurs an extra API call on every gitlab-shell command.
audit_usernames: false
