# {{ ansible_managed }}

[Unit]
Description=Regenerate Diffie-Hellman parameters

[Timer]
OnCalendar={{ dhparam__generate_cron_period }}
RandomizedDelaySec=12h
Persistent=true

[Install]
WantedBy=timers.target
