# {{ ansible_managed }}

options lockd nlm_udpport={{ nfs_server__service_ports['rpc.lockd'] }} nlm_tcpport={{ nfs_server__service_ports['rpc.lockd'] }}
options nfs callback_tcpport={{ nfs_server__service_ports['rpc.nfs-cb'] }}
