/* Override table width restrictions */
/* Source: https://github.com/rtfd/sphinx_rtd_theme/issues/117 */
@media screen and (min-width: 767px) {

   .wy-table-responsive table td {
      /* !important prevents the common CSS stylesheets from overriding
         this as on RTD they are loaded after this stylesheet */
      white-space: normal !important;
   }

   .wy-table-responsive {
      overflow: visible !important;
   }
}

/* Align table elements in the first column to the top */
.rst-content table.docutils td:first-child {
   vertical-align: top;
}
