# {{ ansible_managed }}

#
# Allowed uploadable file extensions and mimetypes are defined here.
# Mimetypes that should be downloadable and not be opened in the
# should be prefixed with a !
#

{{  dokuwiki__local_mime_types_conf|d() }}
