#!{{ ansible_python['executable'] }}

# {{ ansible_managed }}

from __future__ import print_function
from json import loads, dumps
from sys import exit

output = loads("""{{ {'configured': True,
                      'prefix': system_users__prefix
                     } | to_nice_json }}""")

print(dumps(output, sort_keys=True, indent=4))
