# {{ ansible_managed }}

# Configuration installed by debops.machine Ansible role
#
# Create a symlink to fix issues with dynamic MOTD on older OS releases.
# More details: https://unix.stackexchange.com/a/246770

#Type Path                Mode UID  GID  Age Argument
L     /run/motd.dynamic   -    -    -    -   /run/motd
