# {{ ansible_managed }}

# vagrant-libvirt requires access to the libvirt image files to be able to
# package them as boxes. This command allows to grant that access from an
# unprivileged user account.
{{ gitlab_runner__user }}   ALL=(root) NOPASSWD: /usr/bin/env chmod a+r /var/lib/libvirt/images/*.img
