<?php
/**
 * {{ ansible_managed }}
 *
 * This is an example for a farm setup. Simply copy this file to preload.php and
 * uncomment what you need. See http://www.dokuwiki.org/farms for more information.
 * You can also use preload.php for other things than farming, e.g. for moving
 * local configuration files out of the main ./conf directory.
 */

{% if dokuwiki__farm_animals|d() and dokuwiki__farm_animals %}
// set this to your farm directory
if(!defined('DOKU_FARMDIR')) define('DOKU_FARMDIR', '{{ dokuwiki__farm_path }}');

// include this after DOKU_FARMDIR if you want to use farms
include(fullpath(dirname(__FILE__)).'/farm.php');

// you can overwrite the $config_cascade to your liking
//$config_cascade = array(
//);
{% endif %}
