# Configuration file for /sbin/dhclient.
#
# This is a configuration file for dhclient. See dhclient.conf's
#	man page for more information about the syntax of this file
#	and a more comprehensive list of the parameters understood by
#	dhclient.
#
# Normally, if the DHCP server provides reasonable information and does
#	not leave anything out (like the domain name, for example), then
#	few changes must be made to this file, if any.
#

option rfc3442-classless-static-routes code 121 = array of unsigned integer 8;

send host-name = gethostname();
request subnet-mask, broadcast-address, time-offset,
	domain-name, domain-name-servers, domain-search, host-name,
	dhcp6.name-servers, dhcp6.domain-search, dhcp6.fqdn, dhcp6.sntp-servers,
	netbios-name-servers, netbios-scope, interface-mtu,
	ntp-servers;

supersede domain-name "{{ dns_domain }}";
supersede domain-search "{{ dns_domain }}";
supersede domain-name-servers {{ bind_server_ip_for_clients }};

interface "{{ network_primary_interface }}" { also request routers; }

timeout 300;
