# {{ ansible_managed }}

# Enable Kernel Same-page Merging
kernel/mm/ksm/run = {{ '1' if libvirtd__ksm_enabled|bool else '0' }}

# How long to sleep between scans
kernel/mm/ksm/sleep_millisecs = {{ libvirtd__ksm_sleep_milisecs }}

# How many pages to scan in one run
kernel/mm/ksm/pages_to_scan = {{ libvirtd__ksm_pages_to_scan }}
