#!/usr/bin/env bash

# {{ ansible_managed }}

# Automatically create Samba user's home directory
# shellcheck disable=SC2174
mkdir -m 700 -p "{{ samba__homes_path }}/${1}"
chown "${1}":"${1}" "{{ samba__homes_path }}/${1}"

exit 0
